Module quantities::prelude

source ·
This module reexports all macros and types needed to define a quantity.

Re-exports

Macros

  • Converts a numeric literal to an AmountT.

Attribute Macros

  • Generates an enum with the given units (incl. the refunit, if given) as variants, an implemention of trait Unit for this enum and a type alias of Qty with the enum as parameter and named after the given struct.