pub struct Rate<TQ: Quantity, PQ: Quantity> { /* private fields */ }Expand description
The ratio between two related quantity values.
Implementations
Sourceimpl<TQ: Quantity, PQ: Quantity> Rate<TQ, PQ>
impl<TQ: Quantity, PQ: Quantity> Rate<TQ, PQ>
Sourcepub const fn new(
term_amount: AmountT,
term_unit: TQ::UnitType,
per_unit_multiple: AmountT,
per_unit: PQ::UnitType,
) -> Self
pub const fn new( term_amount: AmountT, term_unit: TQ::UnitType, per_unit_multiple: AmountT, per_unit: PQ::UnitType, ) -> Self
Returns a new instance of Rate with attributes equal to given params.
Sourcepub fn from_qty_vals(term: TQ, per: PQ) -> Self
pub fn from_qty_vals(term: TQ, per: PQ) -> Self
Returns a new instance of Rate with attributes extracted from the
given quantity values.
Sourcepub const fn term_amount(&self) -> AmountT
pub const fn term_amount(&self) -> AmountT
Returns the term amount of self.
Sourcepub const fn per_unit_multiple(&self) -> AmountT
pub const fn per_unit_multiple(&self) -> AmountT
Returns the per unit multiple of self.
Sourcepub const fn reciprocal(&self) -> Rate<PQ, TQ>
pub const fn reciprocal(&self) -> Rate<PQ, TQ>
Returns the multiplicative inverse of self