AmountT

Type Alias AmountT 

pub type AmountT = f64;
Type used for the numerical part of a Quantity.

When feature fpdec is off (= default), AmountT is defined as f64 on a 64-bit system or as f32 on a 32-bit system.

When feature fpdec is activated, AmountT is defined as Decimal (imported from crate fpdec).

The macro Amnt! can be used to convert float literals correctly to AmountT depending on the configuration.