Struct quantities::energy::Energy
source · [−]pub struct Energy { /* private fields */ }Expand description
Property that must be transferred to an object in order to perform work on or to heat it.
Definition: Force·Length
Reference unit: Joule (‘J’ = ‘N·m’ = ‘kg·m²/s²’)
Predefined units:
| Symbol | Name | Definition | Equivalent in ‘J’ |
|---|---|---|---|
| Nm | Newton Meter | N·m | 1 |
| Ws | Watt Second | W·s | 1 |
| kWh | Kilowatt Hour | kW·h | 3600000 |