Rate

Struct Rate 

pub struct Rate<TQ: Quantity, PQ: Quantity> { /* private fields */ }
The ratio between two related quantity values.

Implementations

Source

impl<TQ: Quantity, PQ: Quantity> Rate<TQ, PQ>

pub const fn new( term_amount: AmountT, term_unit: TQ::UnitType, per_unit_multiple: AmountT, per_unit: PQ::UnitType, ) -> Self

Returns a new instance of Rate with attributes equal to given params.

pub fn from_qty_vals(term: TQ, per: PQ) -> Self

Returns a new instance of Rate with attributes extracted from the given quantity values.

pub const fn term_amount(&self) -> AmountT

Returns the term amount of self.

pub const fn term_unit(&self) -> TQ::UnitType

Returns the term unit of self.

pub const fn per_unit_multiple(&self) -> AmountT

Returns the per unit multiple of self.

pub const fn per_unit(&self) -> PQ::UnitType

Returns the per unit of self.

pub const fn reciprocal(&self) -> Rate<PQ, TQ>

Returns the multiplicative inverse of self